#
# spec file for package cosmic-panel
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cosmic-panel
Version:        1.0.0~alpha7+0
Release:        1.1
Summary:        A panel for COSMIC DE
License:        GPL-3.0-only
URL:            https://github.com/pop-os/cosmic-panel
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
BuildRequires:  cargo-packaging
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  just
BuildRequires:  pkgconfig
BuildRequires:  rust >= 1.80
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(xkbcommon)

%description
%{summary}.

%prep
%autosetup -a1

%build
just build-release

%install
just rootdir=%{buildroot} prefix=%{_prefix} install
%fdupes %{buildroot}

%check
%{cargo_test}

%files
%license LICENSE.md
%doc README.md
%{_bindir}/%{name}
%{_datadir}/cosmic

%changelog
* Thu Apr 24 2025 Richard Rahl <rrahl0@opensuse.org>
- Update to version 1.0.0~alpha7+0:
  * fix: ceil for scaled width and height
  * Run `cargo clippy --fix`, then `cargo fmt`
  * Store just `ToplevelInfo` instead of tuple
  * Update uses of deprecated `Rectangle::from_loc_and_size`
  * fix: scaling
  * improv: less jank for popup resize
  * Use `patch` to depend on only one version of cctk
  * Update `cctk`, with latest toplevel/workspace protocols
  * make egl_surface current before use
  * fix: get before creating buffer
  * update launch-pad
  * fix: set context to current with surface
  * improv: use damage
  * fix: make egl context current with surfaces
  * fix: handling for stacked autohide panel and static dock.
  * fix: better handling of additional gaps and input zones
  * fix: don't skip adding additional gap if not focused
  * chore: update smithay
  * refactor: autoswitch for popups that have grab
  * feat: subsurface support
* Sat Feb 22 2025 rrahl0@opensuse.org
- Update to version 1.0.0~alpha6+0:
  * release free memory from the heap
  * fix: immediately handle autohover if delay is 0
  * feat: delay for autohover popups
- switch to obs_scm
* Sat Jan 18 2025 rrahl0@opensuse.org
- Update to version 1.0.0~alpha5.1+1:
  * fix: only flag dirty if actual visibility transition occurs
  * perf: optimized cosmic-freedesktop-icons
  * update freedesktop-icons
* Fri Jan 10 2025 rrahl0@opensuse.org
- Update to version 1.0.0~alpha5+1:
  * update deps
  * refactor: timed cleanup
  * fix: layer surface sizes
  * update deps
  * fix: patch
  * fix: patch
  * improv: adjust timeouts
  * improv: more fine grained throttling for frame events
  * update launch-pad not to panic on kill
  * fix: avoid drawing when panel is too small
  * sleep for up to 50ms if there is time left in the iteration timeout
  * fix: typo
* Fri Dec  6 2024 rrahl0@opensuse.org
- Update to version 1.0.0~alpha4+0:
  * fix: rounded rectangle crop position
  * refactor: add namespace
  * fix: namespace
  * fix: typo
  * refactor: intellihide always enabled if autohiding
  * wip: overlap notify
  * feat: intellihide
  * refactor: avoid changing exclusive zone when hiding
  * fix: set focus to new popup
  * refactor: throttle frame events and increase timeouts in general
* Thu Oct 31 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.0.0~alpha3:
  * fix launchpad
  * Make cosmic-protocols truly optional
* Wed Sep 25 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.0.0~alpha2:
  * fix: hide after popup closed and hover lost
  * fix: force resize and relayout after scaling change
  * fix: selection
  * fix: fallback for GL_OES_standard_derivatives extension missing
  * fix: convert usize to isize. Removes clippy errors
  * refactor: process generated pointer events immediately
  * refactor: delay pointer motion on auto-hover until next surface commit
* Thu Aug  8 2024 Richard Rahl <rrahl0@opensuse.org>
- standardize packaging with also fixes for miscellaneous hardcoding
  filenames, using @PARENT_TAG where applicable, and be more specific
  with files in the %%files section (so no non-wanted files are getting
  added
* Wed Aug  7 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.0.0~alpha1:
  * fix: force resize and relayout after scaling change
  * fix: hide after popup closed and hover lost
  * fix: request new dimensions after output update, and clear the surface
  * fix: don't wait for configure after resize
  * fix: unscale margin offset for buttons
  * fix: create dnd egl surface with size of first commit from applet
- enable leap (thanks to vyvir)
* Wed Mar 13 2024 Richard Rahl <rrahl0@proton.me>
- initial packaging
